

#### Forward simulation of genetic drift for a biallelic locus, with constant population size, on a diploid organism ####

## PARAMETERS (the only values to change for simulations)
nbsim=500	# number of simulations (number of populations simulated)
nbgen=100	# generation number
n=1000	# population size
p0 = 0.5	# initial frequency
freq=list()	# replicates of allele frequencies over generations

## SIMULATIONS WOTH A BINOMIAL LAW
for (i in c(1:nbsim)){
	freq[[i]]=prob=p0
	for (j in c(0:nbgen)){
		all=rbinom(1, n, prob)
		prob=all/n
		freq[[i]][j+1]=prob
		}
	}

## SUMMARY STATISTICS CALCULATED FROM THE DATA
mat = matrix(unlist(freq),nr=nbsim,byrow=T) # matrix (row=simulation, column=allelic frequency each generation)
mean.freq = apply(mat,2,mean);mean.freq	# E(p_t) each generation 
var.freq  = apply(mat,2,var);var.freq	# Var(p_t) each generation 
het.freq =  2*mat*(1-mat)
het =  apply(het.freq,2,mean);het
inb  = var.freq/(p0*(1-p0));inb		# inbreeding coefficient each generation (f_t)

## THEORETICAL EXPECTATIONS
exp.mean = p0						# E(p_t) = p0 
exp.var = p0*(1-p0)*(1-(1-(1/(2*n)))^seq(0,nbgen,1)) 	# Var(p_t)= p0*(1-p0)*(1-(1-1/(2*n))^t)
exp.het = 2*p0*(1-p0)*(1-(1/(2*n)))^seq(0,nbgen,1)	# He(t) = 2*p0*(1-p0)*(1-1/(2*n))^t
exp.inb = (1-(1-(1/(2*n)))^seq(0,nbgen,1))*(1-0.001)	# expected inbreeding coefficient assuming inb_0 = 0 which is not true
# if He_0 = 100% => inb = 0  la gnration 0. But here we have He_0 = 0.5 maximum so inb_0 is not 0)

## GRAPHES WITH ALLELE FREQUENCY AND PARAMETERS TRAJECTORIES
par(mfrow=c(1,2))
# with calculated parameter values
plot(seq(0,nbgen,1),freq[[i]], ylim=c(0,1),xlab="generation number",ylab="allele frequency", type="l",main="valeurs calcules des paramtres")
for (i in c(1:nbsim)){
lines(seq(0,nbgen,1),freq[[i]], ylim=c(0,1))
}
lines(seq(0,nbgen,1),mean.freq, col="red",pch=16,lwd=2,lty=2)
lines(seq(0,nbgen,1),mean.freq+var.freq, col="red",lwd=2,lty=2)
lines(seq(0,nbgen,1),mean.freq-var.freq, col="red",lwd=2,lty=2)
lines(seq(0,nbgen,1),het, col="green",lwd=2,lty=2)
lines(seq(0,nbgen,1),inb, col="purple",lwd=2,lty=2)
legend("topleft",c("frquence moyenne (+ variance)", "htrozygotie", "coeff de consanguinit"),col = c("red","green","purple"),text.col = "black", lwd = c(2,2,2),merge = TRUE, bg = 'gray90',cex = 0.7,ncol=1)
# with expected parameter values
plot(seq(0,nbgen,1),freq[[i]], ylim=c(0,1),xlab="generation number",ylab="allele frequency", type="l",main="valeurs thoriques des paramtres")
for (i in c(1:nbsim)){
lines(seq(0,nbgen,1),freq[[i]], ylim=c(0,1))
}
abline(h=exp.mean, col="red",lwd=2)
lines(seq(0,nbgen,1),exp.mean+exp.var, col="red",lwd=2)
lines(seq(0,nbgen,1),exp.mean-exp.var, col="red",lwd=2)
lines(seq(0,nbgen,1),exp.het, col="green",lwd=2)
lines(seq(0,nbgen,1),exp.inb, col="purple",lwd=2)
legend("topleft",c("frquence moyenne (+ variance)","htrozygotie","coeff de consanguinit"),col = c("red","green","purple"),text.col = "black", lwd = c(2,2,2),merge = TRUE, bg = 'gray90',cex = 0.7,ncol=1)

## HETEROZYGOTIE FINALE
het[nbgen]
exp.het[nbgen]

## COEFFICIENT DE CONSANGUINITE FINAL
inb[nbgen]
exp.inb[nbgen]


























